@@ -70,7 +70,7 @@ class API(object):
         print('response:')
         print(response)
         print('response.json():')
-        print(response.json())
+        print(type(response.json()))
         return response.json()
     
     def initialize_price_stream(self, symbol, timeframe):
